# Architecture

The authoritative intended architecture for this repository lives in
[`docs/dev/architecture.md`](https://github.com/kvjrhall/rdflib-reasoning/blob/main/docs/dev/architecture.md).

Use that document when you need the current "as it should be" system design, capability
boundaries, and architectural constraints.
